@@ -11,17 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import TYPE_CHECKING, Any, Dict, Type
+from typing import Any, Dict, Type
 
 import torch
 import transformers
 from torchmetrics import Accuracy, Precision, Recall
+from transformers.models.auto.auto_factory import _BaseAutoModelClass
 
 from lightning_transformers.core import TaskTransformer
 
-if TYPE_CHECKING:
-    from transformers import AutoModel
-
 
 class TextClassificationTransformer(TaskTransformer):
     """Defines ``LightningModule`` for the Text Classification Task.
@@ -36,7 +34,7 @@ class TextClassificationTransformer(TaskTransformer):
     def __init__(
         self,
         *args,
-        downstream_model_type: Type["AutoModel"] = transformers.AutoModelForSequenceClassification,
+        downstream_model_type: Type[_BaseAutoModelClass] = transformers.AutoModelForSequenceClassification,
         **kwargs,
     ) -> None:
         super().__init__(downstream_model_type, *args, **kwargs)
