@@ -11,17 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import TYPE_CHECKING, Any, Dict, List, Type, Union
+from typing import Any, Dict, List, Type, Union
 
 import torch
 import transformers
 from torchmetrics import Accuracy, F1Score, Precision, Recall
+from transformers.models.auto.auto_factory import _BaseAutoModelClass
 
 from lightning_transformers.core import TaskTransformer
 
-if TYPE_CHECKING:
-    from transformers import AutoModel
-
 
 class TokenClassificationTransformer(TaskTransformer):
     """Defines ``LightningModule`` for the Text Classification Task.
@@ -37,7 +35,7 @@ class TokenClassificationTransformer(TaskTransformer):
         self,
         *args,
         labels: Union[int, List[str]],
-        downstream_model_type: Type["AutoModel"] = transformers.AutoModelForTokenClassification,
+        downstream_model_type: Type[_BaseAutoModelClass] = transformers.AutoModelForTokenClassification,
         **kwargs,
     ) -> None:
         num_labels = labels if isinstance(labels, int) else len(labels)
